import sys
import numpy

### to build a conversion dictionary :
### each key/value pair is 'character in sequence':signal_value

dict_conversion_p1m1 = { 'A':1, 'G':1, 'T':-1, 'C':-1}
    

#### conversion functions ####

def convert_string(seq_str, conversion_dict=dict_conversion_p1m1):
    """function for converting a string of ATCG to a signal, using
    a dictionary conversion_dict whose keys are 'A','T','C' and 'G', and whose
    items are the converted signal values. Returns a numpy 1D-array."""
    return numpy.array([conversion_dict[b] for b in seq_str],dtype=int)


def convert_file(filepath, conversion_dict=dict_conversion_p1m1):
    """function for converting a whole file into a signal returned as a numpy
    array. Works for column files and for line files."""
    with open(filepath, 'r') as file:
        seq_str = file.read().strip()
        seq_str = seq_str.replace('\n','')
        return convert_string(seq_str, conversion_dict)
    

if __name__=="__main__":
    
    filein_path = ""

    if len(sys.argv) > 1:
        filein_path = sys.argv[1]
    else:
        sys.stderr.write("Script to convert ATCG sequence files to +1/-1 signals.\nUsage :\npython conversion.py input_file\nError: no input_file provided.\n")
        exit(-1)

    #### to convert a file into a numpy array of +1/-1 :
    signal = convert_file(filein_path)


    ### this script prints the output to stdout so
    numpy.savetxt(sys.stdout, signal, fmt='%d')

    ### you can convert whole files by calling the script :
    ### "$> python conversion.py sequence_ATCG.cgi > sequence_as_numpy_array.txt"
    ### then you can import back the signal using the numpy.loadtxt() function.

    




